not method
not stands for notifier here. It reads the notifier of the provider using WidgetRef
Implementation
N not(WidgetRef ref) => ref.read(notifier);
not stands for notifier here. It reads the notifier of the provider using WidgetRef
N not(WidgetRef ref) => ref.read(notifier);