notX method
not stands for notifier here. It reads the notifier of the provider using Ref
Implementation
N notX(Ref ref) => ref.read(notifier);
not stands for notifier here. It reads the notifier of the provider using Ref
N notX(Ref ref) => ref.read(notifier);