KCurves class

A unified collection of spring‑based curves (implemented inline) along with several additional smooth easing curves defined using our custom _LambdaCurve implementation.

Constructors

KCurves()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

bounceIn Curve
BounceIn is defined as the inverse of BounceOut: f(t) = 1 - bounceOut(1 - t).
final
bounceOut Curve
BounceOut curve: a common bounce effect implementation.
final
bouncySpring Curve
final
decelerate Curve
Decelerate curve: f(t) = 1 - (1-t)^2.
final
defaultIosSpring Curve
final
ease Curve
Ease curve (smoothstep): f(t) = tt(3 - 2*t).
final
easeInOutCirc Curve
Ease In Out Circ: f(t) = (t < 0.5) ? (1 - sqrt(1 - (2t)^2)) / 2 : (sqrt(1 - (-2t + 2)^2) + 1) / 2.
final
easeInOutSine Curve
Ease In Out Sine: f(t) = -(cos(π * t) - 1) / 2.
final
easeOutCirc Curve
Ease Out Circ: f(t) = sqrt(1 - (t - 1)^2).
final
easeOutSine Curve
Ease Out Sine: f(t) = sin((π * t) / 2).
final
fastSlowInOut Curve
FastSlowInOut (approximated via an easeInOutCubic formula): f(t) = { 4t^3 if t < 0.5 1 - (-2t + 2)^3 / 2 if t >= 0.5 }
final
instantSpring Curve
final
interactiveSpring Curve
final
linear Curve
Linear curve: f(t) = t.
final
snappySpring Curve
final

Constants

fastInSlowOut → const Curve