KSpacing class

xxs -> 4 xs -> 8 sm -> 12 md -> 16 lg -> 24 xl -> 32 xxl -> 48 xxxl -> 64

Constructors

KSpacing()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

huge → const double
128
lg → const double
24
massive → const double
256
md → const double
16
sm → const double
12
xl → const double
32
xs → const double
8
xxl → const double
48
xxs → const double
4
xxxl → const double
64