KFilePath class

Simple holder for a possible url and local path alternative.

Use resolve to pick a preferred path (local first by default) and get a normalized, trimmed string along with whether it's a local resource.

Available extensions

Constructors

KFilePath({String? url, String? local})
const
KFilePath.empty()
factory

Properties

containsAnyPath bool

Available on KFilePath, provided by the FilePathExtension extension

no setter
containsLocalPath bool

Available on KFilePath, provided by the FilePathExtension extension

no setter
containsUrlPath bool

Available on KFilePath, provided by the FilePathExtension extension

no setter
hashCode int
The hash code for this object.
no setteroverride
local String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String?
final

Methods

copyWith({String? url, String? local}) KFilePath
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve({bool preferLocal = true}) → ({String? data, bool isLocal})

Available on KFilePath, provided by the FilePathExtension extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(covariant KFilePath other) bool
The equality operator.
override