LogOptions class
Constructors
- LogOptions({bool queryParams = true, bool responseData = false, bool requestData = false, bool headers = false, int maxLogLength = 1024})
-
const
- LogOptions.debugAll()
-
factory
- LogOptions.debugRequest()
-
factory
- LogOptions.debugResponse()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- headers → bool
-
final
- maxLogLength → int
-
final
- queryParams → bool
-
final
- requestData → bool
-
final
- responseData → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited