core/network/rest/rest_api_base library

Classes

CancelToken
Controls cancellation of Dio's requests.
KDeleteRequest<TDecoded>
DELETE request wrapper with optional response decoding.
KDownloadRequest<TDecoded>
KGetRequest<TDecoded>
GET request wrapper with an optional custom operation and response decoder.
KPatchRequest<TDecoded>
PATCH request wrapper with send-progress support and optional response decoding.
KPostRequest<TDecoded>
KPutRequest<TDecoded>
PUT request wrapper with send-progress support and optional response decoding.
KRequest<TDecoded>
KRestApi<CacheType>
Base class for concrete API clients owned by an KRestApiBase.
KRestApiBase
================================================= ApiBase
KRestRequest<TDecoded>
Options
The configuration for a single request. BaseOptions and Options will be merged into one RequestOptions before sending the requests. See Options.compose.

Enums

FileAccessMode
The file access mode when downloading a file, corresponds to a subset of dart:io::FileMode.
RequestMethod

Typedefs

Any = dynamic