KResponse<Raw, Formatted> class

Constructors

KResponse.fromDioResponse(Response<Raw> response, {Formatted decoder(Raw data, Response<Raw> _)?, Object? error})
factory

Properties

data ↔ Raw?
The response payload in specific type.
getter/setter pairinherited
decoded → Formatted?
no setter
decoder → Formatted Function(Raw data, Response<Raw> _)?
final
error Object?
final
extra Map<String, dynamic>
An extra map that you can save your custom information in.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
headers ↔ Headers
Headers for the response.
getter/setter pairinherited
isRedirect bool
Whether the response has been redirected.
getter/setter pairinherited
isSuccess bool
no setter
raw → Raw?
no setter
realUri Uri
Return the final real request URI (may be redirected).
no setterinherited
redirects List<RedirectRecord>
All redirections happened before the response respond.
getter/setter pairinherited
requestOptions ↔ RequestOptions
The RequestOptions used for the corresponding request.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
The HTTP status code for the response.
getter/setter pairinherited
statusMessage String?
Returns the reason phrase associated with the status code.
getter/setter pairinherited
value → Formatted?
Don't call this if you didn't provide a decoder function, otherwise it would return null;
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited