KSomeAsyncNotifier<T> class

Async notifier that exposes an initial default value and can be set later.

Inheritance

Constructors

KSomeAsyncNotifier(T _defaultKey)

Properties

future Future<T>
Obtains a Future that resolves with the first state value that is not AsyncLoading.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
ref Ref
The Ref associated with this notifier.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state AsyncValue<T>
The value currently exposed by this notifier.
getter/setter pairinherited

Methods

build() FutureOr<T>
Initialize an AsyncNotifier.
inherited
listenSelf(void listener(AsyncValue<T>? previous, AsyncValue<T> next), {void onError(Object error, StackTrace stackTrace)?}) → RemoveListener
Listens to changes on the value exposed by this provider.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
runBuild() → void
Executes Notifier.build.
inherited
set(T value) → void
inherited
toString() String
A string representation of this object.
inherited
update(FutureOr<T> cb(T previousState), {FutureOr<T> onError(Object err, StackTrace stackTrace)?}) Future<T>
A function to update state from its previous value, while abstracting loading/error cases for state.
inherited
updateShouldNotify(AsyncValue<T> previous, AsyncValue<T> next) bool
A method invoked when the state exposed by this Notifier changes. It compares the previous and new value, and return whether listeners should be notified.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited