KSomeNotifier<T> class

Generic notifier for arbitrary types with simple set/update helpers.

Inheritance

Constructors

KSomeNotifier(T _defaultKey)

Properties

hashCode int
The hash code for this object.
no setterinherited
ref Ref
The Ref associated with this notifier.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state ↔ T
The value currently exposed by this notifier.
getter/setter pairinherited
stateOrNull → T?
The value currently exposed by this Notifier.
no setterinherited

Methods

build() → T
Initialize a Notifier.
inherited
listenSelf(void listener(T? previous, T next), {void onError(Object error, StackTrace stackTrace)?}) → RemoveListener
Listens to changes on the value exposed by this provider.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
runBuild() → void
Executes Notifier.build.
inherited
set(T value) → void
inherited
toString() String
A string representation of this object.
inherited
update(T cb(T)) → void
inherited
updateShouldNotify(T previous, T next) bool
A method invoked when the state exposed by this Notifier changes. It compares the previous and new value, and return whether listeners should be notified.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited