KSecureHive<T> class

A small wrapper around Hive that uses a platform secure storage-backed encryption key (via flutter_secure_storage) to provide encrypted boxes.

Typical usage: call initialize() before getData/setData.

Constructors

KSecureHive({String secureBoxName = kSecureBoxName, String secureCipherKey = kSecureBoxName})

Properties

hashCode int
The hash code for this object.
no setterinherited
isInitialized bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secureBoxName String
final
secureCipherKey String
final

Methods

getData({required String key}) → T?
initialize() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetAll() Future<bool>
setData({required String key, required T value}) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited