core/utilities/result library

Classes

KResult<T>
A simple wrapper for async operations that can be in loading, success, or error states. status: The current status of the operation (loading, success, or error). data: The data returned from a successful operation (if any). It can be null. message: An error message if the operation failed. It can be null. stackTrace: The stack trace of the error if the operation failed. It can be null.