kickin
library
Classes
ApiResult <Formatted >
A structured result type holding either a successfully decoded value or an error .
AppHive <T >
Simple helper around a Hive box for application-level storage.
BackgroundTransformer
The default Transformer for Dio .
BaseOptions
A set of base settings for each Dio().
BaseOptions and Options will be merged into one RequestOptions before
sending the requests. See Options.compose .
CancelToken
Controls cancellation of Dio 's requests.
CustomPageTransitionsBuilder
A PageTransitionsBuilder that wraps TransitionType for use with MaterialApp's PageTransitionsTheme.
CustomTransitionPage <T >
Enhanced CustomTransitionPage with paired transition duration and iOS swipe-back support.
Dio
Dio enables you to make HTTP requests easily.
DioMixin
ErrorInterceptorHandler
The handler for interceptors to handle error occurred during the request.
FormData
A class to create readable "multipart/form-data" streams.
It can be used to submit forms and file uploads to http server.
FusedTransformer
A Transformer that has a fast path for decoding UTF8-encoded JSON.
If the response is utf8-encoded JSON and no custom decoder is specified in the RequestOptions , this transformer
is significantly faster than the default SyncTransformer and the BackgroundTransformer .
This improvement is achieved by using a fused Utf8Decoder and JsonDecoder to decode the response,
which is faster than decoding the utf8-encoded JSON in two separate steps, since
Dart uses a special fast decoder for this case.
See https://github.com/dart-lang/sdk/blob/5b2ea0c7a227d91c691d2ff8cbbeb5f7f86afdb9/sdk/lib/_internal/vm/lib/convert_patch.dart#L40
The headers class for requests and responses.
HttpClientAdapter
HttpAdapter is a bridge between Dio and HttpClient .
ImageFromMemory
Displays an image from raw memory bytes with optional sizing and a fallback.
Interceptor
Interceptor helps to deal with RequestOptions , Response ,
and DioException during the lifecycle of a request
before it reaches users.
Interceptors
A Queue-Model list for Interceptor s.
InterceptorsWrapper
A helper class to create interceptors in ease.
InternetCheckOption
Options for checking the internet connectivity to an address.
InternetCheckResult
Represents the result of an internet connection check.
InternetConnection
A utility class for checking internet connectivity status.
KAdaptiveImage
A widget that adapts to display an image from either a local file or a network URL, with a fallback widget for error handling.
Only supports file paths that are either local or network URLs. If the path is invalid or unsupported, the fallback widget will be displayed.
KAnimatedSizing
A widget that automatically animates its size when its child's size changes.
KBottomPadding
Adds bottom padding equal to the system bottom inset (keyboard, nav bar)
plus an optional extra height.
KCurves
A unified collection of spring‑based curves (implemented inline)
along with several additional smooth easing curves defined using our
custom _LambdaCurve implementation.
KDeleteRequest <TDecoded >
KDeleteUriRequest <TDecoded >
KDownloadRequest <TDecoded >
KDownloadUriRequest <TDecoded >
KFetchRequest <TDecoded >
KFilePath
Simple holder for a possible url and local path alternative.
KGetRequest <TDecoded >
KGetUriRequest <TDecoded >
KHeadRequest <TDecoded >
KHeadUriRequest <TDecoded >
KHive <T >
Top-level helper to initialize and access app and secure Hive boxes.
KIsolate <TArg , TProgress , TResult >
Runs a single async task in a dedicated isolate with progress reporting.
KIsolateContinuous <TArg , TResult >
A persistent isolate that processes tasks sequentially with priority queuing.
KLazyHive <T >
Simple helper around a Lazy Hive box for application-level storage.
KPatchRequest <TDecoded >
KPatchUriRequest <TDecoded >
KPostRequest <TDecoded >
KPostUriRequest <TDecoded >
KPutRequest <TDecoded >
KPutUriRequest <TDecoded >
KRequest <TDecoded >
KRequestUri <TDecoded >
KResponse <Raw , Formatted >
A custom response wrapper extending Dio's Response .
Contains both the raw payload and a mechanism to decode it into a strongly typed Formatted object.
KRestApi <CacheType >
Base class for concrete API clients owned by a KRestApiBase .
KRestApiBase
=================================================
ApiBase
KRestRequest <TDecoded >
=================================================
KRestRequest
KResult <T >
A simple wrapper for async operations that can be in loading, success, or error states.
status: The current status of the operation (loading, success, or error).
data: The data returned from a successful operation (if any). It can be null.
message: An error message if the operation failed. It can be null.
stackTrace: The stack trace of the error if the operation failed. It can be null.
KScaffold <T >
KScaleGestureWrapper
A wrapper widget that provides a scaling "squish" effect when pressed.
KSmoothCustomScrollView
A CustomScrollView that provides buttery-smooth scrolling on desktop platforms
while maintaining native scroll behavior on mobile.
KSmoothListView
A ListView that provides buttery-smooth scrolling on desktop platforms
while maintaining native scroll behavior on mobile.
KSpacing
xxs -> 4
xs -> 8
sm -> 12
md -> 16
lg -> 24
xl -> 32
xxl -> 48
xxxl -> 64
KText
A lightweight text widget that applies sensible defaults from the theme.
KTopPadding
Adds top padding equal to the system status bar inset plus an optional extra height.
KUriRequest <TDecoded >
=================================================
URI-based request variants
ListParam <T >
Indicates a param being used as queries or form data,
and how does it gets formatted.
LogInterceptor
LogInterceptor is used to print logs during network requests.
It should be the last interceptor added,
otherwise modifications by following interceptors will not be logged.
This is because the execution of interceptors is in the order of addition.
LogOptions
Configuration for controlling the verbosity and format of network logs.
MultipartFile
An upload content that is a part of MultipartRequest.
This doesn't need to correspond to a physical file.
NoTransitionPage <T >
Zero-transition page for instant navigation.
Options
The configuration for a single request.
BaseOptions and Options will be merged into one RequestOptions before
sending the requests. See Options.compose .
PageAnimation
QueuedInterceptor
Interceptor in queue.
QueuedInterceptorsWrapper
A helper class to create QueuedInterceptor in ease.
RedirectRecord
A record that records the redirection happens during requests,
including status code, request method, and the location.
RequestInterceptorHandler
The handler for interceptors to handle before the request has been sent.
RequestOptions
The internal request option class that is the eventual result after
BaseOptions and Options are composed.
Response <T >
The Response class contains the payload (could be transformed)
that respond from the request, and other information of the response.
ResponseBody
The response wrapper class for adapters.
ResponseInterceptorHandler
The handler for interceptors to handle after respond.
ScrollIntensityConfig
Configuration for scroll intensity/feel
SmoothScrollController
Manages smooth scroll state and handles pointer events.
SmoothScrollPhysics
Custom scroll physics for smooth desktop scrolling.
SyncTransformer
If you want to custom the transformation of request/response data,
you can provide a Transformer by your self, and replace
the transformer by setting the Dio.transformer .
Transformer
Transformer allows changes to the request/response data before
it is sent/received to/from the server.
TransitionType
Enums
DioExceptionType
The exception enumeration indicates what type of exception
has happened during requests.
FileAccessMode
The file access mode when downloading a file, corresponds to a subset of
dart:io::FileMode .
InternetStatus
Enum representing the status of internet connectivity.
KScrollIntensity
Defines the intensity/feel of the smooth scrolling
KSmoothScrollMode
Defines when smooth scrolling should be applied
KWorkPriority
Priority levels for KIsolateContinuous task scheduling.
ListFormat
Specifies the array format (a single parameter with multiple parameter
or multiple parameters with the same name).
and the separator for array items.
LogPart
Defines which parts of an HTTP request or response should be logged.
ResponseType
Indicates which transformation should be applied to the response data.
Typedefs
ConnectivityCheckCallback
= Future <InternetCheckResult > Function(InternetCheckOption option )
A callback function for checking if a specific internet endpoint is
reachable.
DecodedCallback <TDecoded >
= TDecoded Function(dynamic data , Response _ )
DefaultTransformer
= SyncTransformer
DioError
= DioException
DioError describes the exception info when a request failed.
DioErrorType
= DioExceptionType
Deprecated in favor of DioExceptionType and will be removed in future major versions.
DioExceptionReadableStringBuilder
= String Function(DioException e )
The readable string builder's signature of
DioException.readableStringBuilder .
DioMediaType
= MediaType
The type (alias) for specifying the content-type of the MultipartFile.
ErrorOverrideCallback <Raw >
= Object ? Function(Response <Raw > data , Object ? error , [StackTrace ? st ])
The signature that iterates header fields.
InterceptorErrorCallback
= void Function(DioException error , ErrorInterceptorHandler handler )
The signature of Interceptor.onError .
InterceptorSendCallback
= void Function(RequestOptions options , RequestInterceptorHandler handler )
The signature of Interceptor.onRequest .
InterceptorSuccessCallback
= void Function(Response response , ResponseInterceptorHandler handler )
The signature of Interceptor.onResponse .
JsonDecodeCallback
= FutureOr Function(String )
The callback definition for decoding a JSON string.
JsonEncodeCallback
= FutureOr <String > Function(Object )
The callback definition for encoding a JSON object.
ProgressCallback
= void Function(int count , int total )
The type of a progress listening callback when sending or receiving data.
RequestEncoder
= FutureOr <List <int > > Function(String request , RequestOptions options )
The type of a request encoding callback.
ResponseDecoder
= FutureOr <String ? > Function(List <int > responseBytes , RequestOptions options , ResponseBody responseBody )
The type of a response decoding callback.
ResponseStatusFn
= bool Function(Response response )
A Callback Function to decide whether the request succeeded or not.
TransitionBuilder
= Widget Function(BuildContext context , Animation <double > animation , Animation <double > secondaryAnimation , Widget child )
ValidateStatus
= bool Function(int ? status )
The type of a response status code validate callback.