A ProviderListenable that exposes an AsyncValue and can be converted into a Future using the future property.
This is used by FutureProvider and StreamProvider to expose their asynchronous values.
- Implemented types
-
- ProviderListenable<
AsyncValue< ValueT> >
- ProviderListenable<
- Available extensions
- Annotations
-
- @publicInMisc
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
WidgetRef ref) → AsyncValue< StateT> -
Available on AsyncProviderListenable<
StateT> , provided by the KAsyncProviderExtension extension -
readX(
Ref ref) → AsyncValue< StateT> -
Available on AsyncProviderListenable<
StateT> , provided by the KAsyncProviderExtension extension -
toString(
) → String -
A string representation of this object.
inherited
-
watch(
WidgetRef ref) → AsyncValue< StateT> -
Available on AsyncProviderListenable<
StateT> , provided by the KAsyncProviderExtension extension -
watchX(
Ref ref) → AsyncValue< StateT> -
Available on AsyncProviderListenable<
StateT> , provided by the KAsyncProviderExtension extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited