onTapUp property
The callback triggered when the pointer stops contacting the screen. You can use delayReverseDuration to delay the release animation.
Implementation
final void Function(TapUpDetails details)? onTapUp;
The callback triggered when the pointer stops contacting the screen. You can use delayReverseDuration to delay the release animation.
final void Function(TapUpDetails details)? onTapUp;