widgets/layout/app_padding library

Classes

KBottomPadding
Adds bottom padding equal to the system bottom inset (keyboard, nav bar) plus an optional extra height.
KTopPadding
Adds top padding equal to the system status bar inset plus an optional extra height.