KScaffold<T> class

Inheritance

Constructors

KScaffold({Key? key, bool extendBodyBehindAppBar = false, EdgeInsets appBarPadding(EdgeInsets apply)?, bool extendBody = false, Color? backgroundColor, bool? resizeToAvoidBottomInset, Widget? appBar, bool applyDefaultAppBar = false, Widget? floatingActionButton, Widget? bottomNavigationBar, SystemUiOverlayStyle? systemUiOverlayStyle, bool canPop = true, PopInvokedWithResultCallback? onPopInvokedWithResult, EdgeInsets? viewPadding, required String title, String? subtitle, Widget? titleWidget, Widget? trailingWidget, Widget? leadingWidget, required Widget body, void onBackButtonPressed()?, Color? appBarBackgroundColor, Widget? drawer, Widget? footer, EdgeInsets? footerPadding})
const

Properties

appBar Widget?
final
appBarBackgroundColor Color?
final
appBarPadding EdgeInsets Function(EdgeInsets apply)?
final
applyDefaultAppBar bool
final
backgroundColor Color?
final
body Widget
final
bottomNavigationBar Widget?
final
canPop bool
final
drawer Widget?
final
extendBody bool
final
extendBodyBehindAppBar bool
final
floatingActionButton Widget?
final
final
footerPadding EdgeInsets?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leadingWidget Widget?
final
onBackButtonPressed → void Function()?
final
onPopInvokedWithResult PopInvokedWithResultCallback?
final
resizeToAvoidBottomInset bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String?
final
systemUiOverlayStyle SystemUiOverlayStyle?
final
title String
final
titleWidget Widget?
final
trailingWidget Widget?
final
viewPadding EdgeInsets?
final

Methods

build(BuildContext context, WidgetRef ref) Widget
Describes the part of the user interface represented by this widget.
override
createElement() → ConsumerStatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _ConsumerState
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

appBarBuilderArgs AppBarBuilderArgs
no getter