KText class

A lightweight text widget that applies sensible defaults from the theme.

Wraps Text and provides convenient parameters for common styling needs, plus an optional tooltip when text is truncated.

Inheritance

Constructors

KText(String data, {Key? key, TextStyle? style, double? fontSize, FontWeight fontWeight = FontWeight.normal, Color? color, TextAlign? textAlign, TextOverflow? overflow, bool? softWrap, int? maxLines, double? height, double? letterSpacing, bool wrapWithTooltip = false, String? fontFamily})
const

Properties

color Color?
final
data String
final
fontFamily String?
final
fontSize double?
final
fontWeight FontWeight
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
letterSpacing double?
final
maxLines int?
final
overflow TextOverflow?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
softWrap bool?
final
style TextStyle?
final
textAlign TextAlign?
final
wrapWithTooltip bool
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited