SmoothScrollController class
Manages smooth scroll state and handles pointer events.
This controller intercepts scroll events and drives continuous frame-by-frame updates for smooth, responsive scrolling.
Constructors
- SmoothScrollController({required ScrollController scrollController, required KScrollIntensity intensity, required SmoothScrollPhysics? customPhysics, required bool reverse, required TickerProvider vsync})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollController → ScrollController
-
final
- vsync → TickerProvider
-
final
Methods
-
dispose(
) → void -
handlePointerSignal(
PointerSignalEvent event) → void - Handles pointer scroll events from the Listener widget
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateConfig(
{required KScrollIntensity intensity, required SmoothScrollPhysics? customPhysics, required bool reverse}) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited