KNotifierX<N extends Notifier<S> , S> extension
- on
-
- NotifierProvider<
N, S>
- NotifierProvider<
Methods
-
expand<
T> (WidgetRef ref, T selector(WidgetRef r, NotifierProvider< N, S> s)) → T -
Available on NotifierProvider<
N, S> , provided by the KNotifierX extension -
expandX<
T> (Ref ref, T selector(Ref r, NotifierProvider< N, S> s)) → T -
Available on NotifierProvider<
N, S> , provided by the KNotifierX extension -
not(
WidgetRef ref) → N -
Available on NotifierProvider<
not stands for notifier here. It reads the notifier of the provider using WidgetRefN, S> , provided by the KNotifierX extension -
notX(
Ref ref) → N -
Available on NotifierProvider<
not stands for notifier here. It reads the notifier of the provider using RefN, S> , provided by the KNotifierX extension -
watchNot(
WidgetRef ref) → N -
Available on NotifierProvider<
N, S> , provided by the KNotifierX extension -
watchNotX(
Ref ref) → N -
Available on NotifierProvider<
N, S> , provided by the KNotifierX extension