LogOptions class
Constructors
-
LogOptions({Set<
LogPart> parts = const {LogPart.queryParams}, int maxLogLength = 1024}) -
const
- LogOptions.debugAll()
-
factory
- LogOptions.debugRequest()
-
factory
- LogOptions.debugResponse()
-
factory
- LogOptions.none()
-
const
- LogOptions.normal()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxLogLength → int
-
final
-
parts
→ Set<
LogPart> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited