KDoubleNotifier class
A simple double notifier with convenience defaults.
Constructors
- KDoubleNotifier([double _defaultKey = 0.0])
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ref → Ref
-
The Ref associated with this notifier.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ double
-
The value currently exposed by this notifier.
getter/setter pairinherited
- stateOrNull → double?
-
The value currently exposed by this Notifier.
no setterinherited
Methods
-
build(
) → double -
Initialize a Notifier.
inherited
-
listenSelf(
void listener(double? previous, double next), {void onError(Object error, StackTrace stackTrace)?}) → RemoveListener -
Listens to changes on the value exposed by this provider.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
runBuild(
) → void -
Executes Notifier.build.
inherited
-
set(
double value) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
double cb(double)) → void -
inherited
-
updateShouldNotify(
double previous, double next) → bool -
A method invoked when the state exposed by this Notifier changes.
It compares the previous and new value, and return whether listeners
should be notified.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited