AppHive<T> class
Simple helper around a Hive box for application-level storage.
Provides convenience methods for initialize, setData, getData, and
watching changes by key.
Properties
- boxName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isInitialized → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteData(
{required String key}) → Future< void> -
getData(
{required String key}) → T? -
initialize(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resetAll(
String acknowledge) → Future< bool> -
setData(
{required String key, required T value}) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
watchChanges(
{required String key}) → Stream< void> -
watchData(
{required String key}) → Stream< T?>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited