widgets/misc/adaptive_image library
Classes
- ImageFromMemory
- Displays an image from raw memory bytes with optional sizing and a fallback.
- KAdaptiveImage
- A widget that adapts to display an image from either a local file or a network URL, with a fallback widget for error handling. Only supports file paths that are either local or network URLs. If the path is invalid or unsupported, the fallback widget will be displayed.
- KFilePath
-
Simple holder for a possible
urlandlocalpath alternative.