KAdaptiveImage class
A widget that adapts to display an image from either a local file or a network URL, with a fallback widget for error handling. Only supports file paths that are either local or network URLs. If the path is invalid or unsupported, the fallback widget will be displayed.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- KAdaptiveImage
Constructors
Properties
- alignment → Alignment
-
final
- cacheHeight → int?
-
final
- cacheWidth → int?
-
final
- centerSlice → Rect?
-
final
- color → Color?
-
final
- colorBlendMode → BlendMode?
-
final
- excludeFromSemantics → bool
-
final
- fallbackWidget → Widget
-
final
- filterQuality → FilterQuality
-
final
- fit → BoxFit?
-
final
- gaplessPlayback → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAntiAlias → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- matchTextDirection → bool
-
final
-
opacity
→ Animation<
double> ? -
final
- path → KFilePath
-
final
- preferLocal → bool
-
final
- repeat → ImageRepeat
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → double
-
final
- semanticLabel → String?
-
final
- size → Size?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited